Welcome to the Abilian Core documentation — Abilian 0.1 documentation

# Welcome to the Abilian Core documentation

Welcome to Abilian Core’s documentation.

Abilian Core is an enterprise application development platform based on the Flask micro-framework, the SQLAlchemy ORM, good intentions and best practices (for some value of “best”).

The full documentation is available on http://docs.abilian.com/.

It builds on powerful and well documented Python librairies, mainly:

- Flask
- SQLAlchemy
- WTForms

This documentation will assume that a developer already has some knowledge of these librairies.

## Contents

- About Abilian Core
  - Goals & principles
  - Features
  - Current status
  - Roadmap & getting involved
  - Licence
  - Credits
- Installing Abilian Core
  - Testing
- Constributing to Abilian Core
  - Project on GitHub
  - License and copyright
  - Build Status
  - Releasing
- Coding standard
  - Additional rules
  - Notes
- API
  - Package `abilian`
  - Package `abilian.plugin`
  - Package `abilian.core`
  - Package `abilian.services`
  - Package `abilian.web`
  - Package `abilian.testing`
- Changelog for Abilian Core
  - 0.4.6 (unreleased)
  - 0.4.5 (2015-10-15)
  - 0.4.4 (2015-08-07)
  - 0.4.3 (2015-07-29)
  - 0.4.2 (2015-07-29)
  - 0.4.1 (2015-07-21)
  - 0.4.0 (2015-07-15)
  - 0.3.6 (2015-05-27)
  - 0.3.5 (2015-05-27)
  - 0.3.4 (2015-04-14)
  - 0.3.3 (2015-03-31)
  - 0.3.2 (2014-12-23)
  - 0.3.1 (2014-12-23)
  - 0.3.0 (2014-12-23)
  - 0.2.0 (2014-08-07)
  - 0.1.4 (2014-03-27)
  - 0.1.3 (2014-02-03)
  - 0.1.2 (2014-01-11)
  - 0.1.1 (2013-12-26)
  - 0.1 (2013-12-13)
- Credits
  - Design, programming
  - Art (images, icons)

## Indices and tables

- Index
- Module Index
- Search Page